# 介绍
- telegram转发 修改自:[tgcf](https://github.com/aahnik/tgcf)
- 支持代理设置,如需代理请设置环境变量,例如:`export TG_PROXY="socks5://127.0.0.1:7890"`

# 安装
`pipx install my-tgcf`
# 使用
1. `tgw`
2. 浏览器打开:http://localhost:8501